;*************************************************************
;*********************TM57PE10********************************
;*************************************************************
;-------------------------------------------------------------
;					-F register-
;-------------------------------------------------------------	
INDF			EQU	00H		;Indirect addressing register
TIMER0			EQU	01H		;Timer0 content
PC				EQU	02H		;Program counter
STAT			EQU	03H		;Status register
TO			EQU	4			;WDT time out flag	
PD			EQU	3			;Sleep mode flag	
Z			EQU	2			;Zero Flag
DC			EQU	1			;Decimal Carry Flag
C			EQU	0			;Carry Flag

FSR				EQU	04H		
GBIT2		EQU	7			;general purpose bit
							;bit(0-6) File select register,indirect address mode pointer
							
PAD				EQU	05H		;PortA pin or "data register"
PBD				EQU	06H		;PortB pin or "data register"
PCD				EQU	07H		;PortC pin or "data register"

INTIE			EQU	08H   	;Interrupt control register
PWM0IE		EQU	7
TMR2IE		EQU	6			;Bit6 "0" for disable Timer1 interrupt,"1" for enable Timer2 interrupt      
CMPIE		EQU	5
TMR0IE		EQU	4			;Bit4 "0" for disable Timer0    interrupt,"1" for enable Timer0 interrupt      
WKTIE		EQU	3			;Bit3 "0" for disable WKT interrupt,"1" for enable WKT interrupt
EXT2IE		EQU	2			;Bit2 "0" for disable INT2(PA7) interrupt,"1" for enable INT1(PA7) interrupt
EXT1IE		EQU	1			;Bit1 "0" for disable INT1(PB0) interrupt,"1" for enable INT0(PB0) interrupt
EXT0IE		EQU	0			;Bit0 "0" for disable INT0(PA0) interrupt,"1" for enable INT0(PA0) interrupt

INTF			EQU	09H		;Interrupt event register
PWM0F		EQU	7
TMR2F		EQU	6			;Timer1 interrupt event pending flag
CMPF		EQU	5
TMR0F		EQU	4			;Timer0 interrupt event pending flag
WKTF		EQU	3			;WKT interrupt event pending flag
XT2F		EQU	2			;INT2(PA7)interrupt event pending flag
XT1F		EQU	1			;INT1(PB0)interrupt event pending flag
XT0F		EQU	0      		;INT0(PA0)interrupt event pending flag

PWM0DUTY		EQU	12H		;PWMA duty 8-bit MSB
PWM1DUTY		EQU	13H		;PWMA duty 2-bit LSB(BIT7~6)

RES_CN		EQU	14H			;Resources	register
SELSUB		EQU	7			;sleect sub-clk as cpuclk
STPFCK		EQU	6			;stop fast clock
SUBE		EQU	5			;sub-clk enable
CMPO		EQU	3			;COMP state
CLRTM2		EQU	2			;write 1 to clear TM2 timer
STOPTM0		EQU	1			;Stop  TM0 timer counting
CLRPWM0		EQU	0			;PWM0 clear and hold

							
;-------------------------------------------------------------
;					-R register-
;-------------------------------------------------------------							
TIM0_CN			EQU	02H		;timer worke register
T0IEDGE		EQU	5			;T0I(PA2) rising(0)/falling(1) edge to increase timer0/psc count
SELT0I		EQU	4			;Timer/psc clock source is intstuction cycle(0) /T0I pin(1)
							;Bit(0-3) TM0PSC
                            ;0000:Timer1 clock is "TIMER0 input clock" divide by 1
                            ;0001:Timer1 clock is "TIMER0 input clock" divide by 2
                            ;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
							;0111:Timer1 clock is "TIMER0 input clock" divide by 128
PWRDOWN			EQU	03H		;Power-down mode register--writer this register to enter power down moe
CLRWDT			EQU	04H		;WDT/WKT control register,writer this register to clear WDT/WKT
PAE				EQU	05H		;PortA control register,each bit control its corresponding PIN (0:INPUT   1:OUTPUT)
PBE				EQU	06H		;PortB control register,each bit control its corresponding PIN (0:INPUT   1:OUTPUT)
PA_PULL			EQU	08H		;PortA(Bit6~Bit0) pull up register,"0" for PullUp resistor is Enable,"1" for Disable
PB_PULL			EQU	09H		;PortB(Bit5~Bit0) pull up register,"0" for PullUp resistor is Enable,"1" for Disable
BPITW			EQU	0bH		;Miscellaneous register
PWMAOUT		EQU   6         ;Bit6 "0" for disable PWMA output to PA1,"1" for enable PWMA output to PA1
PWMBOUT		EQU   5         ;Bit5 "0" for disable PWMB output to PA6,"1" for enable PWMB output to PA6
INT0EDGE	EQU   4         ;Bit4 "0" for falling edge to triger INT0PA0,"1" for rising edge to triger INT1
CLK2PIN		EQU   3         ;0=no intstruction clock output to PA3 pin;1=instrucyion clock output to PA3 pin for external/internal RCmode

							;WKTPSC (Bit1-0)
                           	;00:13mS
                           	;01:25mS
                           	;10:50mS                                                                                                                                                                                                                                                                                                            
                           	;11:100mS

NO_PMP			EQU	0EH		;OTP ROM Pump control
TESTREG			EQU	0FH		;test mode register,for manufacturer only,user do not write it
PWMO_PERIOD		EQU	10H
TIME_DIVIDE		EQU	11H		;time and divide control
							;Bit(0-1) PWM0 pre-scale0:div1,1:div2,2:div4,3:div8,   
                            ;Bit2  PWM0 positive output to PA1 pin 
                            ;Bit3  PWM1 positive output to Pb5 pin   
PAWKUP			EQU	13H		;Enable PA1-PA6 pin low level wake up
TIMER_SOURCE	EQU	14H		;timer clock  source
							;BIT(0-1) SUB-clk type 0:sxt 1:wrc 2:xrc
							;bit(2-3) timer2 interrupt is timer2 clock divide by
							;0:32768 1:16348 2:8192 3:127
TME2CLK		EQU	4			;timer2 clock source 0:slow clock 1:cpuclk/128

CMP_CONTROL		EQU	17H		;CMP control register
CMPEN		EQU	7			;CMP enable
CMPEDGE		EQU	6			;CMP interrupt edge ,0:falling edge, 1:rising edge
CMPOE		EQU	5			;CMP output to pin enable 
CMPINNS		EQU	4			;CMP INN source select 0:IN0- 1:IN0+
							;BIT(0-3)OP INP Source select
							;0000: internal vref 0
							;0001: internal vref 1
							;0010: internal vref 2
							;0011: internal vref 3
							;0100: internal vref 4
							;0101: internal vref 6	
							;1110: internal vref 14							
							;1111: external	pin
PBWKUP			EQU	18H		;Enable	PB6-PB1 pin low level wake up
;*************************************************************
;				Bay  user 
;*************************************************************
ACC_Save			equ		20h
Status_Save			equ		21h


